@@ -8,18 +8,14 @@ magrittr::`%>%`
 #' @importFrom magrittr %<>%
 magrittr::`%<>%`
 
-#' @export
-#' @importFrom magrittr %$%
-magrittr::`%$%`
-
 #' @export
 #' @importFrom zeallot %<-%
 zeallot::`%<-%`
 
 #' @export
-#' @importFrom tibble tibble
-tibble::tibble
+#' @importFrom dplyr tibble
+dplyr::tibble
 
 #' @export
-#' @importFrom tibble as_tibble
-tibble::as_tibble
+#' @importFrom dplyr as_tibble
+dplyr::as_tibble
